==> foundation-2.6.1.tgz: package/TorsosMaleFemale/TorsosMaleFemale.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const TorsosMaleFemale = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M90.937 63.235c-.185-1.43-.998-2.653-2.166-3.218L73.748 52.85l-6.353-3.03c2.775-1.747 5.028-4.445 6.503-7.695a20.872 20.872 0 001.866-8.625c0-1.753-.278-3.416-.666-5.023-1.89-7.782-7.968-13.515-15.263-13.515-6.494 0-12.011 4.557-14.48 11.047a20.422 20.422 0 00-.67 2.043c-.347 1.3-.613 2.64-.725 4.035-.037.465-.057.936-.057 1.413 0 .415.012.826.036 1.234a20.622 20.622 0 002.056 7.87c1.523 3.121 3.78 5.695 6.527 7.35l-6.084 2.833-15.51 7.223c-1.011.474-1.761 1.447-2.074 2.62a4.781 4.781 0 00-.159 1.229v17.043c0 2.284 1.591 4.136 3.557 4.136H87.42c1.965 0 3.557-1.852 3.557-4.136V63.859c0-.211-.013-.42-.04-.624z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M39.227 50.335l2.85-1.452c-3.165-4.206-5.065-9.555-5.065-15.383 0-4.041.917-7.85 2.531-11.21-1.566-.772-3.238-1.212-4.983-1.212-8.365 0-15.186 9.612-15.544 21.665H19v5.119c0 1.074.871 1.945 1.945 1.945h7.089c.081.051.159.108.24.157l-17.448 8.122c-1.087.511-1.804 1.739-1.804 3.111v13.771c0 1.846 1.289 3.341 2.875 3.341h11.531v-14.45c0-3.739 2.068-7.121 5.275-8.623l10.524-4.901z"
  }));
});
TorsosMaleFemale.displayName = 'TorsosMaleFemale';
export const TorsosMaleFemaleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/TorsosMaleFemale/TorsosMaleFemale.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var TorsosMaleFemale = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M90.937 63.235c-.185-1.43-.998-2.653-2.166-3.218L73.748 52.85l-6.353-3.03c2.775-1.747 5.028-4.445 6.503-7.695a20.872 20.872 0 001.866-8.625c0-1.753-.278-3.416-.666-5.023-1.89-7.782-7.968-13.515-15.263-13.515-6.494 0-12.011 4.557-14.48 11.047a20.422 20.422 0 00-.67 2.043c-.347 1.3-.613 2.64-.725 4.035-.037.465-.057.936-.057 1.413 0 .415.012.826.036 1.234a20.622 20.622 0 002.056 7.87c1.523 3.121 3.78 5.695 6.527 7.35l-6.084 2.833-15.51 7.223c-1.011.474-1.761 1.447-2.074 2.62a4.781 4.781 0 00-.159 1.229v17.043c0 2.284 1.591 4.136 3.557 4.136H87.42c1.965 0 3.557-1.852 3.557-4.136V63.859c0-.211-.013-.42-.04-.624z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M39.227 50.335l2.85-1.452c-3.165-4.206-5.065-9.555-5.065-15.383 0-4.041.917-7.85 2.531-11.21-1.566-.772-3.238-1.212-4.983-1.212-8.365 0-15.186 9.612-15.544 21.665H19v5.119c0 1.074.871 1.945 1.945 1.945h7.089c.081.051.159.108.24.157l-17.448 8.122c-1.087.511-1.804 1.739-1.804 3.111v13.771c0 1.846 1.289 3.341 2.875 3.341h11.531v-14.45c0-3.739 2.068-7.121 5.275-8.623l10.524-4.901z"
  }));
});
TorsosMaleFemale.displayName = 'TorsosMaleFemale';
export var TorsosMaleFemaleDimensions = {
  height: 100,
  width: 100
};
